@@ -109,6 +109,10 @@ func FindMatches(store interface {
 		if err != nil {
 			log.Warnf("unable to determine linux distribution: %+v", err)
 		}
+		if d != nil && d.Disabled() {
+			log.Warnf("unsupported linux distribution: %s", d.Name())
+			return match.Matches{}
+		}
 	}
 
 	packagesProcessed, vulnerabilitiesDiscovered := trackMatcher()
@@ -117,7 +121,7 @@ func FindMatches(store interface {
 		defaultMatcher = stock.NewStockMatcher(stock.MatcherConfig{UseCPEs: true})
 	}
 	for _, p := range packages {
-		packagesProcessed.N++
+		packagesProcessed.Increment()
 		log.Debugf("searching for vulnerability matches for pkg=%s", p)
 
 		matchAgainst, ok := matcherIndex[p.Type]
@@ -131,7 +135,7 @@ func FindMatches(store interface {
 			} else {
 				logMatches(p, matches)
 				res.Add(matches...)
-				vulnerabilitiesDiscovered.N += int64(len(matches))
+				vulnerabilitiesDiscovered.Add(int64(len(matches)))
 			}
 		}
 	}
